@@ -79,6 +79,7 @@ ADDON_TO_DEP.update({
     'systemd':
         'debhelper (>= 9.20160709~) | debhelper-compat | '
         'dh-sequence-systemd | dh-systemd',
+    'vim_addon': 'dh_vim-addon | dh-sequence-vim-addon',
 })
 
 need = []
@@ -136,7 +137,7 @@ with control as updater:
 
         for field in ['Build-Depends', 'Build-Depends-Indep',
                       'Build-Depends-Arch']:
-            for unused1, existing, unused2 in parse_relations(
+            for _unused1, existing, _unused2 in parse_relations(
                     updater.source.get(field, '')):
                 if is_relation_implied(parsed, existing):
                     is_implied = True
