@@ -2,19 +2,21 @@
 
 import asyncio
 from functools import partial
-from lintian_brush.changelog import ChangelogUpdater
+from debmutate.changelog import ChangelogEditor
 from lintian_brush import min_certainty
 from lintian_brush.fixer import (
+    fixed_lintian_tag,
     net_access_allowed,
     meets_minimum_certainty,
+    warn,
+    fixed_lintian_tags,
+    report_result,
     )
 import re
 import socket
-from warnings import warn
 
 certainty = 'certain'
 debbugs = None
-tags = set()
 
 
 async def valid_bug(package, bug):
@@ -58,7 +60,9 @@ def fix_close_colon(package, m):
     (valid, bug_certainty) = check_bug(package, bugno)
     if meets_minimum_certainty(bug_certainty) and valid:
         certainty = min_certainty([certainty, bug_certainty])
-        tags.add("possible-missing-colon-in-closes")
+        fixed_lintian_tag(
+            'all', "possible-missing-colon-in-closes",
+            info='%s #%d' % (m.group('closes'), bugno))
         return '%s: #%d' % (m.group('closes'), bugno)
     else:
         return m.group(0)
@@ -70,13 +74,15 @@ def fix_close_typo(package, m):
     (valid, bug_certainty) = check_bug(package, bugno)
     if meets_minimum_certainty(bug_certainty) and valid:
         certainty = min_certainty([certainty, bug_certainty])
-        tags.add('misspelled-closes-bug')
+        fixed_lintian_tag(
+            'all', 'misspelled-closes-bug',
+            info='#%s' % m.group('bug'))
         return '%ss: #%s' % (m.group('close'), m.group('bug'))
     else:
         return m.group(0)
 
 
-with ChangelogUpdater() as updater:
+with ChangelogEditor() as updater:
     for block in updater.changelog:
         for i, change in enumerate(block._changes):
             change = re.sub(
@@ -91,11 +97,9 @@ with ChangelogUpdater() as updater:
             block._changes[i] = change
 
 
-if tags == set(['possible-missing-colon-in-closes']):
-    print("Add missing colon in closes line.")
-elif tags == set(['misspelled-closes-bug']):
-    print("Fix misspelling of Close => Closes.")
+if fixed_lintian_tags() == set(['possible-missing-colon-in-closes']):
+    report_result("Add missing colon in closes line.", certainty=certainty)
+elif fixed_lintian_tags() == set(['misspelled-closes-bug']):
+    report_result("Fix misspelling of Close ⇒ Closes.", certainty=certainty)
 else:
-    print("Fix formatting of bug closes.")
-print("Fixed-Lintian-Tags: %s" % ", ".join(sorted(tags)))
-print("Certainty: %s" % certainty)
+    report_result("Fix formatting of bug closes.", certainty=certainty)
