@@ -306,7 +306,8 @@ INFO_FIXERS = {
     "shell-script-fails-syntax-check": PURE_FN_SUB,
     "manpage-has-errors-from-man":
         (r"^" + PATH_MATCH + " ([^[]*)", r"\2 [\1]"),
-    "groff-message": (r"^" + PATH_MATCH + " ([^[ ]+)", r"\2 [\1]"),
+    "groff-message": (
+        r"^" + PATH_MATCH + " ([0-9]+): (.+)$", r"\2: \3 [\1:*]"),
     "source-contains-prebuilt-javascript-object": [
         PURE_FN_SUB,
         (r"^(?P<path>[^[ ].+) line length is .*", r"[\1]")],
@@ -320,7 +321,7 @@ INFO_FIXERS = {
         (r"^(?P<path>[^[ ].+) \*", r"[\1]"),
         PURE_FN_SUB],
     "spelling-error-in-binary":
-        (r"^(?P<path>[^[ ]+) (.+) ([^[]+)$", r"\2 \3 [\1]"),
+        (r"^" + PATH_MATCH + " (.+) ([^[/\*]+)$", r"\2 \3 [\1]"),
     "very-long-line-length-in-source-file": [
         (PATH_MATCH +
          r" line ([0-9]+) is ([0-9]+) characters long \(>([0-9]+)\)",
@@ -369,6 +370,8 @@ INFO_FIXERS = {
     "privacy-breach-google-adsense": (
         r"^" + PATH_MATCH + r" \(choke on: ([^\)]+)\)$",
         r"(choke on: \2) [\1]"),
+    "systemd-service-file-refers-to-unusual-wantedby-target": (
+        "^" + PATH_MATCH + r" ([^[ ]+)$", r"\2 [\1]"),
 }
 
 
